Tutorial
========

Using EnPT and Polymer for water surfaces
******************************************

Here we will use the EnMAP processing tool (EnPT_) to produce a Level-2A, as in EnPT tutorial_, but considering
the Polymer_ algorithm and water surfaces.

In this tutorial, we also use the graphical user interface (GUI) within the EnMAP-Box_ in QGIS_.

.. _Polymer: https://www.hygeos.com/polymer
.. _EnPT tutorial: https://enmap.git-pages.gfz-potsdam.de/GFZ_Tools_EnMAP_BOX/EnPT/doc/tutorial.html
.. _EnPT: https://git.gfz-potsdam.de/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT
.. _EnMAP-Box: https://www.enmap.org/data_tools/enmapbox/
.. _QGIS: https://www.qgis.org


Requirements
------------

Software installation is at the EnPT tutorial_ followed by  :ref:`installation` section.

Data
""""

You download a data subset for this tutorial at:
`here <https://git.gfz-potsdam.de/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/-/blob/master/tests/data/EnMAP_Level_1B/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__rows700-730.zip>`__.

After using the subset you can try with the full image tile located at:
`here <https://www.enmap.org/data/test_data/L1B_Arcachon_3.zip>`__.


Processing data from Level-1B to Level-2A using Polymer
--------------------------------------------------------

Using the combined mode output values are in Wm2.

Using the water mode output should be Wm2/sr.


